artist Package
==============

:mod:`artist` Package
---------------------

.. automodule:: artist.__init__
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`multi_plot` Module
------------------------

.. automodule:: artist.multi_plot
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`plot` Module
------------------

.. automodule:: artist.plot
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`recursive_smooth` Module
------------------------------

.. automodule:: artist.recursive_smooth
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`simple_smooth` Module
---------------------------

.. automodule:: artist.simple_smooth
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`utils` Module
-------------------

.. automodule:: artist.utils
    :members:
    :undoc-members:
    :show-inheritance:

